import{s as a,c as s,a as e,C as t}from"./chunk-727SXJPM-DVyKb0dl.js";import{_ as i}from"./mermaid.core-ZUtnug0n.js";import"./chunk-FMBD7UC4-iNpdKIO0.js";import"./chunk-ND2GUHAM-DI7cbFmX.js";import"./chunk-55IACEB6-NzLyvSb8.js";import"./chunk-2J33WTMH-CBxjogVR.js";import"./index-DZLIXILO.js";var n={parser:e,get db(){return new t},renderer:s,styles:a,init:i(r=>{r.class||(r.class={}),r.class.arrowMarkerAbsolute=r.arrowMarkerAbsolute},"init")};export{n as diagram};
