// Force strict mode and setup for ESM
"use strict";
import {
  FETCH_TIMEOUT_MS,
  UpdateCheckTimeoutError,
  checkForUpdates,
  checkForUpdatesDetailed,
  classifyUpdateCheckError,
  describeUpdateCheckFailure,
  fetchGlobalNpmUpdateInfo,
  runGlobalNpm
} from "./chunk-C6OQY3AM.js";
import "./chunk-RNNQYOBE.js";
import "./chunk-DP3IHZGG.js";
import "./chunk-CH2UCUF7.js";
import "./chunk-URK542T4.js";
import "./chunk-VJNBRRZG.js";
import "./chunk-OWAK7LMW.js";
import "./chunk-HVFUW4JT.js";
import "./chunk-5M6IDOMF.js";
import "./chunk-TWPJO254.js";
import "./chunk-H6XPXXMH.js";
import "./chunk-AOHY3QJ3.js";
import "./chunk-5NNHICSA.js";
import "./chunk-SHN4KHDK.js";
import "./chunk-JXVC2PL3.js";
import "./chunk-KRXPRVGL.js";
import "./chunk-6PVPNMXU.js";
import "./chunk-OV2BALJJ.js";
import "./chunk-IRH27ZC2.js";
import "./chunk-QHWCP53L.js";
import "./chunk-TEGJSJDF.js";
import "./chunk-TIRRPCFS.js";
import "./chunk-O6GEWCJA.js";
import "./chunk-T26EAKDL.js";
import "./chunk-CPBF7KYF.js";
import "./chunk-4KP2F2TE.js";
import "./chunk-3APUUXRF.js";
import "./chunk-THVU3RNH.js";
import "./chunk-LHKCY7DY.js";
import "./chunk-6FMJLI5M.js";
import "./chunk-CBBP4BMC.js";
import "./chunk-S6LOFUVP.js";
import "./chunk-K623ENWT.js";
import "./chunk-AQ37AY7B.js";
import "./chunk-N4ACHWNH.js";
import "./chunk-ZPJWUGCS.js";
import "./chunk-D4HTUMGX.js";
import "./chunk-NAVJD2PQ.js";
import "./chunk-LOY7RWQG.js";
import "./chunk-E6CJ2SMM.js";
import "./chunk-DGEIYUC3.js";
import "./chunk-MPHPFVKK.js";
import "./chunk-GLNBDYUX.js";
import "./chunk-DJ2GSRLV.js";
import "./chunk-JHNMFZLP.js";
import "./chunk-Z3S5EMOW.js";
import "./chunk-2J3OJGTL.js";
import "./chunk-P3QQPMQA.js";
import "./chunk-XQK4XXTN.js";
import "./chunk-GLCZKT5V.js";
import "./chunk-QDK4F2N5.js";
import "./chunk-SCUZ3ZCL.js";
import "./chunk-VGC4I5JJ.js";
import "./chunk-3I6DUGQD.js";
import "./chunk-7ULQIS27.js";
import "./chunk-MM7TH7ZM.js";
import "./chunk-6WSXKTJR.js";
import "./chunk-46UV252V.js";
import "./chunk-ZBVS26BY.js";
import "./chunk-Q3T5KA2V.js";
import "./chunk-R2XWGR75.js";
import "./chunk-HC45LTEN.js";
import "./chunk-QARJNL2V.js";
import "./chunk-W4RQUHY3.js";
import "./chunk-G7XXKQYS.js";
import "./chunk-E2BHWIDT.js";
import "./chunk-VOQXFAY5.js";
import "./chunk-75DOP5OR.js";
import "./chunk-DMTGGOSA.js";
import "./chunk-YQ3U5MUC.js";
import "./chunk-AMDSOFFV.js";
import "./chunk-QUGAUQGJ.js";
import "./chunk-5O2XNYP6.js";
import "./chunk-J2S4EL5Y.js";
export {
  FETCH_TIMEOUT_MS,
  UpdateCheckTimeoutError,
  checkForUpdates,
  checkForUpdatesDetailed,
  classifyUpdateCheckError,
  describeUpdateCheckFailure,
  fetchGlobalNpmUpdateInfo,
  runGlobalNpm
};
